@@ -58,36 +58,35 @@ API
 .. autofunction:: selectChecker
 """
 import abc
+import datetime
+import decimal
 import os
 import sys
 import types
-import datetime
-import decimal
 import weakref
 
-from zope.i18nmessageid import Message
+import zope.interface.declarations
 import zope.interface.interface
 import zope.interface.interfaces
-import zope.interface.declarations
+from zope.i18nmessageid import Message
 from zope.interface import Interface
 from zope.interface import directlyProvides
 from zope.interface import implementer
 from zope.interface.interfaces import IDeclaration
 from zope.interface.interfaces import IInterface
 
+from zope.security._compat import PURE_PYTHON
+from zope.security._compat import implementer_if_needed
+from zope.security._definitions import thread_local
+from zope.security.interfaces import ForbiddenAttribute
 from zope.security.interfaces import IChecker
 from zope.security.interfaces import INameBasedChecker
 from zope.security.interfaces import ISecurityProxyFactory
-from zope.security.interfaces import ForbiddenAttribute
 from zope.security.interfaces import Unauthorized
-from zope.security._definitions import thread_local
-from zope.security._compat import CLASS_TYPES
-from zope.security._compat import PYTHON2
-from zope.security._compat import PURE_PYTHON
-from zope.security._compat import implementer_if_needed
 from zope.security.proxy import Proxy
 from zope.security.proxy import getChecker
 
+
 try:
     from zope.exceptions import DuplicationError
 except ImportError:  # pragma: no cover
@@ -108,7 +107,7 @@ def ProxyFactory(object, checker=None):
 
     The proxy checker is looked up if not provided.
     """
-    if type(object) is Proxy:
+    if isinstance(object, Proxy):
         if checker is None or checker is getChecker(object):
             return object
         else:
@@ -136,6 +135,8 @@ directlyProvides(ProxyFactory, ISecurityProxyFactory)
 
 # This import represents part of the API for the proxy module
 from . import proxy  # noqa: E402 module level import not at top
+
+
 proxy.ProxyFactory = ProxyFactory
 
 
@@ -194,7 +195,7 @@ def canAccess(obj, name):
 
 
 @implementer(INameBasedChecker)
-class CheckerPy(object):
+class CheckerPy:
     """
     The Python reference implementation of
     :class:`zope.security.interfaces.INameBasedChecker`.
@@ -277,7 +278,7 @@ class CheckerPy(object):
 
     def proxy(self, value):
         'See IChecker'
-        if type(value) is Proxy:
+        if isinstance(value, Proxy):
             return value
         checker = getattr(value, '__Security_checker__', None)
         if checker is None:
@@ -292,7 +293,7 @@ Checker = CheckerPy  # in case no C optimizations
 
 
 # Helper class for __traceback_supplement__
-class TracebackSupplement(object):
+class TracebackSupplement:
 
     def __init__(self, obj):
         self.obj = obj
@@ -302,7 +303,7 @@ class TracebackSupplement(object):
         try:
             cls = self.obj.__class__
             if hasattr(cls, "__module__"):
-                s = "%s.%s" % (cls.__module__, cls.__name__)
+                s = "{}.{}".format(cls.__module__, cls.__name__)
             else:  # pragma: no cover XXX
                 s = str(cls.__name__)
             result.append("   - class: " + s)
@@ -311,7 +312,7 @@ class TracebackSupplement(object):
         try:
             cls = type(self.obj)
             if hasattr(cls, "__module__"):
-                s = "%s.%s" % (cls.__module__, cls.__name__)
+                s = "{}.{}".format(cls.__module__, cls.__name__)
             else:  # pragma: no cover XXX
                 s = str(cls.__name__)
             result.append("   - type: " + s)
@@ -320,7 +321,7 @@ class TracebackSupplement(object):
         return "\n".join(result)
 
 
-class Global(object):
+class Global:
     """A global object that behaves like a string.
 
     We want this to behave as a global, meaning it's pickled
@@ -339,8 +340,8 @@ class Global(object):
         return self.__name__
 
     def __repr__(self):
-        return "%s(%s,%s)" % (self.__class__.__name__,
-                              self.__name__, self.__module__)
+        return "{}({},{})".format(self.__class__.__name__,
+                                  self.__name__, self.__module__)
 
 
 CheckerPublic = Global('CheckerPublic')
@@ -409,7 +410,7 @@ def MultiChecker(specs):
     data = {}
 
     for spec in specs:
-        if type(spec) is tuple:
+        if isinstance(spec, tuple):
             names, permission_id = spec
             if IInterface.providedBy(names):
                 names = names.names(all=True)
@@ -467,7 +468,7 @@ def getCheckerForInstancesOf(class_):
     return _checkers.get(class_)
 
 
-DEFINABLE_TYPES = CLASS_TYPES + (types.ModuleType,)
+DEFINABLE_TYPES = (type, types.ModuleType)
 
 
 def defineChecker(type_, checker):
@@ -514,10 +515,12 @@ if _c_available:  # pragma: no cover
         _c_available = False
 
 if _c_available:  # pragma: no cover
-    from zope.security._zope_security_checker import _checkers, selectChecker
-    from zope.security._zope_security_checker import NoProxy, Checker
-    from zope.security._zope_security_checker import _defaultChecker
+    from zope.security._zope_security_checker import Checker
+    from zope.security._zope_security_checker import NoProxy
     from zope.security._zope_security_checker import _available_by_default
+    from zope.security._zope_security_checker import _checkers
+    from zope.security._zope_security_checker import _defaultChecker
+    from zope.security._zope_security_checker import selectChecker
     zope.interface.classImplements(Checker, INameBasedChecker)
 
 
@@ -535,7 +538,7 @@ class CombinedChecker(Checker):
     +====================+====================+=====================================+
     | ok                 | anything           | ok (checker 2 never called)         |
     +--------------------+--------------------+-------------------------------------+
-    | Unathorized        | ok                 | ok                                  |
+    | Unauthorized       | ok                 | ok                                  |
     +--------------------+--------------------+-------------------------------------+
     | Unauthorized       | Unauthorized       | Unauthorized                        |
     +--------------------+--------------------+-------------------------------------+
@@ -584,7 +587,7 @@ class CombinedChecker(Checker):
                 raise unauthorized_exception
 
 
-class CheckerLoggingMixin(object):
+class CheckerLoggingMixin:
     """
     Debugging mixin for checkers.
 
@@ -606,26 +609,26 @@ class CheckerLoggingMixin(object):
 
     def check(self, object, name):
         try:
-            super(CheckerLoggingMixin, self).check(object, name)
+            super().check(object, name)
             if self.verbosity > 1:
                 if name in _available_by_default:
                     self._log('[CHK] + Always available: %s on %r'
                               % (name, object), 2)
                 else:
                     self._log(
-                        '[CHK] + Granted: %s on %r' % (name, object), 2)
+                        '[CHK] + Granted: {} on {!r}'.format(name, object), 2)
         except Unauthorized:
             self._log(
-                '[CHK] - Unauthorized: %s on %r' % (name, object))
+                '[CHK] - Unauthorized: {} on {!r}'.format(name, object))
             raise
         except ForbiddenAttribute:
             self._log(
-                '[CHK] - Forbidden: %s on %r' % (name, object))
+                '[CHK] - Forbidden: {} on {!r}'.format(name, object))
             raise
 
     def check_getattr(self, object, name):
         try:
-            super(CheckerLoggingMixin, self).check(object, name)
+            super().check(object, name)
             if self.verbosity > 1:
                 if name in _available_by_default:
                     self._log(
@@ -637,28 +640,31 @@ class CheckerLoggingMixin(object):
                         % (name, object), 2)
         except Unauthorized:
             self._log(
-                '[CHK] - Unauthorized getattr: %s on %r' % (name, object))
+                '[CHK] - Unauthorized getattr: {} on {!r}'.format(name, object)
+            )
             raise
         except ForbiddenAttribute:
             self._log(
-                '[CHK] - Forbidden getattr: %s on %r' % (name, object))
+                '[CHK] - Forbidden getattr: {} on {!r}'.format(name, object))
             raise
 
     __setitem__ = check_getattr
 
     def check_setattr(self, object, name):
         try:
-            super(CheckerLoggingMixin, self).check_setattr(object, name)
+            super().check_setattr(object, name)
             if self.verbosity > 1:
                 self._log(
-                    '[CHK] + Granted setattr: %s on %r' % (name, object), 2)
+                    '[CHK] + Granted setattr: {} on {!r}'.format(
+                        name, object), 2)
         except Unauthorized:
             self._log(
-                '[CHK] - Unauthorized setattr: %s on %r' % (name, object))
+                '[CHK] - Unauthorized setattr: {} on {!r}'.format(
+                    name, object))
             raise
         except ForbiddenAttribute:
             self._log(
-                '[CHK] - Forbidden setattr: %s on %r' % (name, object))
+                '[CHK] - Forbidden setattr: {} on {!r}'.format(name, object))
             raise
 
 
@@ -713,7 +719,7 @@ def moduleChecker(module):
 _available_by_default[:] = [
     '__lt__', '__le__', '__eq__',
     '__gt__', '__ge__', '__ne__',
-    '__hash__', '__nonzero__',
+    '__hash__', '__bool__',
     '__class__', '__providedBy__', '__implements__',
     '__repr__', '__conform__',
     '__name__', '__parent__',
@@ -779,14 +785,10 @@ _basic_types = {
     datetime.date: NoProxy,
     datetime.time: NoProxy,
     datetime.tzinfo: NoProxy,
+    type({}.values()): NoProxy,
+    type({}.keys()): NoProxy,
+    type({}.items()): NoProxy,
 }
-if PYTHON2:  # pragma: no cover
-    _basic_types[long] = NoProxy  # noqa: F821 undefined name 'long'
-    _basic_types[unicode] = NoProxy  # noqa: F821 undefined name 'unicode'
-else:
-    _basic_types[type({}.values())] = NoProxy
-    _basic_types[type({}.keys())] = NoProxy
-    _basic_types[type({}.items())] = NoProxy
 
 try:
     import pytz
@@ -814,12 +816,8 @@ BasicTypes_examples = {
     Message: Message('message', domain='hello')
 }
 
-if PYTHON2:  # pragma: no cover
-    BasicTypes_examples[unicode] = u'uabc'  # noqa: F821 undefined name
-    BasicTypes_examples[long] = long(65536)  # noqa: F821 undefined name
 
-
-class _Sequence(object):
+class _Sequence:
     def __len__(self):
         raise NotImplementedError()
 
@@ -845,26 +843,25 @@ _default_checkers = {
                         'get', 'has_key', 'copy', '__str__', 'keys',
                         'values', 'items', 'iterkeys', 'iteritems',
                         'itervalues', '__contains__']),
-    list: NamesChecker(['__getitem__', '__getslice__', '__len__', '__iter__',
+    list: NamesChecker(['__getitem__', '__len__', '__iter__',
                         '__contains__', 'index', 'count', '__str__',
                         '__add__', '__radd__', ]),
     set: _setChecker,
     frozenset: _setChecker,
     # XXX: actually decimal.Decimal has more methods, which are unlisted here
     #      so expect ForbiddenAttribute on such
-    decimal.Decimal: NamesChecker(['__nonzero__', '__cmp__', '__eq__',
+    decimal.Decimal: NamesChecker(['__bool__', '__cmp__', '__eq__',
                                    '__ne__', '__hash__',
                                    '__str__',
                                    '__neg__', '__pos__', '__abs__',
                                    '__add__', '__radd__',
                                    '__sub__', '__rsub__',
                                    '__mul__', '__rmul__',
-                                   '__div__', '__truediv__',
-                                   '__rdiv__', '__rtruediv__',
+                                   '__truediv__', '__rtruediv__',
                                    '__divmod__', '__rdivmod__',
                                    '__mod__', '__rmod__',
                                    '__floordiv__', '__rfloordiv__',
-                                   '__float__', '__int__', '__long__',
+                                   '__float__', '__int__',
                                    '__pow__', '__rpow__',
                                    'adjusted', 'as_tuple', 'compare',
                                    'max', 'min', 'normalize',
@@ -873,7 +870,7 @@ _default_checkers = {
                                    'to_eng_string', 'to_integral']),
 
     # YAGNI: () a rock
-    tuple: NamesChecker(['__getitem__', '__getslice__', '__add__', '__radd__',
+    tuple: NamesChecker(['__getitem__', '__add__', '__radd__',
                          '__contains__', '__len__', '__iter__',
                          '__str__']),
     Proxy: NoProxy,
@@ -882,10 +879,12 @@ _default_checkers = {
     types.MethodType: _callableChecker,
     types.BuiltinFunctionType: _callableChecker,
     types.BuiltinMethodType: _callableChecker,
+    # method-wrapper
+    type(().__repr__): _callableChecker,
     type: _typeChecker,
     types.ModuleType: lambda module: _checkers.get(module, _namedChecker),
-    type(iter([])): _iteratorChecker,  # Same types in Python 2.2.1,
-    type(iter(())): _iteratorChecker,  # different in Python 2.3.
+    type(iter([])): _iteratorChecker,
+    type(iter(())): _iteratorChecker,
     type(iter({})): _iteratorChecker,
     type(iter(set())): _iteratorChecker,
     type(iter(_Sequence())): _iteratorChecker,
@@ -896,8 +895,7 @@ _default_checkers = {
         _implied=CheckerPublic,
         subscribe=CheckerPublic,
         # To iterate, Python calls __len__ as a hint.
-        # Python 2 ignores AttributeErrors, but Python 3
-        # lets them pass.
+        # AttributeErrors are passed.
         __len__=CheckerPublic,
     ),
     zope.interface.interface.Method: InterfaceChecker(
@@ -908,14 +906,6 @@ _default_checkers = {
     zope.interface.declarations.Declaration: _Declaration_checker,
     abc.ABCMeta: _typeChecker,
 }
-if PYTHON2:  # pragma: no cover
-    _default_checkers[types.ClassType] = _typeChecker
-    _default_checkers[types.InstanceType] = _instanceChecker
-    # slot description
-    _default_checkers[type(().__getslice__)] = _callableChecker
-    _default_checkers[type({}.iteritems())] = _iteratorChecker
-    _default_checkers[type({}.iterkeys())] = _iteratorChecker
-    _default_checkers[type({}.itervalues())] = _iteratorChecker
 
 
 def _fixup_dictlike(dict_type):
@@ -934,11 +924,8 @@ def _fixup_dictlike(dict_type):
 
 
 def _fixup_odict():
-    # OrderedDicts have three different implementations: Python 2 (pure
-    # python, returns generators and lists), Python <=3.4 (pure Python,
-    # uses view classes) and CPython 3.5+ (implemented in C). These should
-    # all be iterable.
     from collections import OrderedDict
+
     # The `_fixup_dictlike` is detected as undefined because it is deleted
     # later on but this function is called beforehand:
     _fixup_dictlike(OrderedDict)  # noqa: F821 undefined name '_fixup_dictlike'
@@ -991,8 +978,8 @@ def _fixup_zope_interface():
     # checking process at all, much like BTrees, so NoProxy is necessary for
     # compatibility. On Python 3, prior to this, iteration was simply not
     # allowed.
-    from zope.interface import providedBy
     from zope.interface import alsoProvides
+    from zope.interface import providedBy
 
     class I1(Interface):
         pass
@@ -1001,12 +988,12 @@ def _fixup_zope_interface():
         pass
 
     @implementer(I1)
-    class Obj(object):
+    class Obj:
         pass
 
     o = Obj()
 
-    # This will be athe zope.interface.implementedBy from the class
+    # This will be the zope.interface.implementedBy from the class
     # a zope.interface.declarations.Implements
     _default_checkers[type(providedBy(o))] = NoProxy
 
@@ -1021,7 +1008,7 @@ del _fixup_zope_interface
 
 def _fixup_itertools():
     # itertools.groupby is a built-in custom iterator type introduced
-    # in python2.4. It should have the same checker as other built-in
+    # in Python 2.4. It should have the same checker as other built-in
     # iterators.
 
     # Also, itertools._grouper also needs to be exposed as an
@@ -1046,40 +1033,24 @@ def _fixup_itertools():
         return x
     iterable = (1, 2, 3)
     pred_iterable = (pred, iterable)
-    missing_in_py3 = {'ifilter', 'ifilterfalse', 'imap',
-                      'izip', 'izip_longest'}
-    missing_in_py2 = {'zip_longest', 'accumulate', 'compress',
-                      'combinations', 'combinations_with_replacement'}
-    missing = missing_in_py3 if sys.version_info[0] >= 3 else missing_in_py2
     for func, args in (
             ('count', ()),
             ('cycle', ((),)),
             ('dropwhile', pred_iterable),
-            ('ifilter', pred_iterable),
-            ('ifilterfalse', pred_iterable),
-            ('imap', pred_iterable),
             ('islice', (iterable, 2)),
-            ('izip', (iterable,)),
-            ('izip_longest', (iterable,)),
             ('permutations', (iterable,)),
             ('product', (iterable,)),
             ('repeat', (1, 2)),
             ('starmap', pred_iterable),
             ('takewhile', pred_iterable),
             ('tee', (iterable,)),
-            # Python 3 additions
             ('zip_longest', (iterable,)),
             ('accumulate', (iterable,)),
             ('compress', (iterable, ())),
             ('combinations', (iterable, 1)),
             ('combinations_with_replacement', (iterable, 1)),
     ):
-        try:
-            func = getattr(itertools, func)
-        except AttributeError:
-            assert func in missing, "Expected %s but not found" % (func,)
-            # The following line is hit on PY2, but it doesn't always show:
-            continue  # pragma: no cover
+        func = getattr(itertools, func)
 
         result = func(*args)
         if func == itertools.tee:
